==> plinth_0.24.0.tar.xz: plinth-0.24.0/README.md <==
[![pipeline status](https://salsa.debian.org/freedombox-team/plinth/badges/master/pipeline.svg)](https://salsa.debian.org/freedombox-team/plinth/commits/master)
[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/shields-badge.svg)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)
[![Debian Unstable](https://badges.debian.net/badges/debian/unstable/plinth/version.svg)](https://packages.debian.org/unstable/plinth)
[![Debian Testing](https://badges.debian.net/badges/debian/testing/plinth/version.svg)](https://packages.debian.org/testing/plinth)
[![Debian Stable](https://badges.debian.net/badges/debian/stable/plinth/version.svg)](https://packages.debian.org/stable/plinth)

# FreedomBox Service (Plinth)

The core functionality and web front-end of
[FreedomBox](https://freedombox.org/).

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=aboutfreedombox.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=tor1.png" width="425px" style="margin: 5px">

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=emailclient.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=newsfeed.png" width="425px" style="margin: 5px">

# Description

FreedomBox is a community project to develop, design and promote
personal servers running free software for private, personal
communications.  It is a networking appliance designed to allow
interfacing with the rest of the Internet under conditions of
protected privacy and data security.  It hosts applications such as
blog, wiki, website, social network, email, web proxy and a Tor relay,
on a device that can replace your Wi-Fi router, so that your data
stays with you.

This module, called FreedomBox Service and also know as Plinth, is the core
functionality and web interface to the functions of the FreedomBox. It is
extensible and provides various applications of FreedomBox as modules. Each
module or application provides simplified user interface to control the
underlying functionality. As FreedomBox can act as a wireless router, it is
possible to configure networking. It also allows configuration of basic system
parameters such as time zone, hostname and automatic upgrades.

You can find more information about FreedomBox Service (Plinth) on the
[Plinth Wiki](https://wiki.debian.org/FreedomBox/Plinth) page,
the [FreedomBox Wiki](https://wiki.debian.org/FreedomBox/) and the
[FreedomBox Manual](https://wiki.debian.org/FreedomBox/Manual).

# Getting Started

See the INSTALL.md file for additional details and dependencies. To install run:

    $ sudo python3 setup.py install

Run FreedomBox Service (Plinth) on the local system with:

    $ sudo plinth

# Contributing

See the HACKING file for contributing to FreedomBox Service (Plinth).

# Localization

[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/287x66-white.png)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)

==> plinth_19.14.tar.xz: plinth-19.14/README.md <==
[![pipeline status](https://salsa.debian.org/freedombox-team/plinth/badges/master/pipeline.svg)](https://salsa.debian.org/freedombox-team/plinth/commits/master)
[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/shields-badge.svg)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)
[![Debian Unstable](https://badges.debian.net/badges/debian/unstable/plinth/version.svg)](https://packages.debian.org/unstable/plinth)
[![Debian Testing](https://badges.debian.net/badges/debian/testing/plinth/version.svg)](https://packages.debian.org/testing/plinth)
[![Debian Stable](https://badges.debian.net/badges/debian/stable/plinth/version.svg)](https://packages.debian.org/stable/plinth)

# FreedomBox Service (Plinth)

The core functionality and web front-end of
[FreedomBox](https://freedombox.org/).

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=aboutfreedombox.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=tor1.png" width="425px" style="margin: 5px">

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=emailclient.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=newsfeed.png" width="425px" style="margin: 5px">

# Description

FreedomBox is a community project to develop, design and promote
personal servers running free software for private, personal
communications.  It is a networking appliance designed to allow
interfacing with the rest of the Internet under conditions of
protected privacy and data security.  It hosts applications such as
blog, wiki, website, social network, email, web proxy and a Tor relay,
on a device that can replace your Wi-Fi router, so that your data
stays with you.

This module, called FreedomBox Service and also know as Plinth, is the core
functionality and web interface to the functions of the FreedomBox. It is
extensible and provides various applications of FreedomBox as modules. Each
module or application provides simplified user interface to control the
underlying functionality. As FreedomBox can act as a wireless router, it is
possible to configure networking. It also allows configuration of basic system
parameters such as time zone, hostname and automatic upgrades.

You can find more information about FreedomBox Service (Plinth) on the
[Plinth Wiki](https://wiki.debian.org/FreedomBox/Plinth) page,
the [FreedomBox Wiki](https://wiki.debian.org/FreedomBox/) and the
[FreedomBox Manual](https://wiki.debian.org/FreedomBox/Manual).

# Getting Started

To have a running FreedomBox, first install Debian (Buster or higher) on a clean
machine. Then run:

    ```
    $ sudo apt install freedombox
    ```

Full instructions are available on FreedomBox
[Manual](https://wiki.debian.org/FreedomBox/Manual/)'s
[QuickStart](https://wiki.debian.org/FreedomBox/Manual/QuickStart) page.

For instructions on running the service on a local machine from source code, see
INSTALL.md. For instructions on setting up for development purposes, see
HACKING.md.

# Contributing

See the [HACKING.md](https://salsa.debian.org/freedombox-team/plinth/blob/master/HACKING.md) file for contributing to FreedomBox Service (Plinth).

# Localization

[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/287x66-white.png)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)
